@@ -29,7 +29,7 @@ var Interceptor      = require('./interceptor').Interceptor,
     IORedisObserver    = require('../observers/ioredis-observer').IORedisObserver,
     MssqlObserver    = require('../observers/mssql-observer').MssqlObserver,
     PgSqlObserver    = require('../observers/pgsql-observer').PgSqlObserver,
-    // GRpcObserver     = require('../observers/grpc-observer').GRpcObserver,
+    GRpcObserver     = require('../observers/grpc-observer').GRpcObserver,
     ApolloObserver   = require('../observers/apollo-server-observer').ApolloServerObserver,
     PrismaObserver  = require('../observers/prisma-observer').PrismaObserver,
     OracleObserver  = require('../observers/oracle-observer').OracleObserver,
@@ -1105,7 +1105,7 @@ NodeAgent.prototype.loadObserves = function() {
     observes.push(IORedisObserver);
     observes.push(MssqlObserver);
     observes.push(PgSqlObserver);
-    // observes.push(GRpcObserver);
+    observes.push(GRpcObserver);
     observes.push(ApolloObserver);
     observes.push(PrismaObserver);
     observes.push(OracleObserver);
