@@ -6,15 +6,18 @@
 
 var conf = require('../../conf/configure'),
     TraceContextManager = require('../../trace/trace-context-manager'),
-    KeyGen = require('../../util/keygen'),
-    HashUtil = require('../../util/hashutil'),
-    Logger          = require('../../logger'),
-    Long = require('long');
+    Logger          = require('../../logger');
 
 function ActiveTransaction() {}
 ActiveTransaction.prototype.getActiveStats = function () {
     var stats = new Array(5).fill(0);
     var en = TraceContextManager.getContextEnumeration();
+
+    if(conf.getProperty('debug_activestats_size_enabled', false)){
+        Logger.print("WHATAP-DEBUG-ACTIVESTATS-1", "Size: " + TraceContextManager.size(), false);
+        Logger.print("WHATAP-DEBUG-ACTIVESTATS-2", "Pid: " + process.pid, false);
+    }
+
     try {
         while (en.hasMoreElements()) {
             var ctx = en.nextElement();
