@@ -19,6 +19,8 @@ const {Buffer} = require("buffer");
 const shimmer = require('../core/shimmer');
 const os = require('os');
 const Transfer = require('../util/transfer');
+const IPUtil = require('../util/iputil');
+const UserIdUtil = require('../util/userid-util');
 
 var _exts = new Set([".css", ".js", ".png", ".htm", ".html", ".gif", ".jpg", ".css", ".txt", ".ico"]);
 
@@ -145,6 +147,31 @@ HttpObserver.prototype.__createTransactionObserver = function (callback, isHttps
                 self.__endTransaction(null, ctx, req, res);
             });
 
+            // 브라우저가 닫히면 진행 중인 외부 HTTP 요청도 정리하고 TX_HTTPC, TX_END 전송
+            res.on('close', function () {
+                if (ctx == null) {
+                    return;
+                }
+
+                // 진행 중인 모든 외부 HTTP 요청에 대해 TX_HTTPC 전송
+                // if (ctx.activeHttpcList && ctx.activeHttpcList.length > 0) {
+                //     ctx.activeHttpcList.forEach(function(httpcInfo) {
+                //         try {
+                //             let urls = `${httpcInfo.host}:${httpcInfo.port}${httpcInfo.url}`;
+                //             let httpcDatas = [urls, httpcInfo.mcallee];
+                //             ctx.elapsed = Date.now() - httpcInfo.start_time;
+                //             TraceHttpc.isSlowHttpc(ctx);
+                //             AsyncSender.send_packet(PacketTypeEnum.TX_HTTPC, ctx, httpcDatas);
+                //         } catch (e) {
+                //             Logger.printError('WHATAP-243', 'Failed to send TX_HTTPC on close', e, false);
+                //         }
+                //     });
+                //     ctx.activeHttpcList = [];
+                // }
+
+                self.__endTransaction(null, ctx, req, res);
+            });
+
             try {
                 AsyncSender.send_packet(PacketTypeEnum.TX_START, ctx, datas)
                 return callback.apply(this, arguments);
@@ -181,6 +208,9 @@ function initCtx(req, res) {
         return null;
     }
 
+    // 진행 중인 외부 HTTP 요청 정보를 저장 (여러 개 동시 추적)
+    ctx.activeHttpcList = [];
+
     // RemoteIP
     var remote_addr;
     try {
@@ -188,19 +218,16 @@ function initCtx(req, res) {
         if(remote_addr.includes(',')) {
             remote_addr = remote_addr.split(',')[0].trim();
         }
-        remote_addr=IPUtil.checkIp4(remote_addr);
-        ctx.remoteIp = IPUtil.stringToInt(remote_addr);
+        ctx.remoteIp = IPUtil.checkIp4(remote_addr);
         switch (conf.trace_user_using_type || 3) {
             case 1:
                 ctx.userid = Long.fromNumber(ctx.remoteIp);
-                MeterUsers.add(ctx.userid);
                 break;
             case 2:
                 // MeterUsers.add(ctx.userid);
                 break;
             case 3:
                 ctx.userid = UserIdUtil.getUserId(req, res, 0);
-                MeterUsers.add(ctx.userid);
                 break;
         }
     } catch (e) {
@@ -495,10 +522,20 @@ HttpObserver.prototype.inject = function (mod, moduleName) {
                     ctx.httpc_host = options.host || options.hostname || '';
                     ctx.httpc_port = options.port || -1;
                     ctx.active_httpc_hash = true;
-                    
+
                     if (ctx.httpc_port < 0) {
                         ctx.httpc_port = 80
                     }
+
+                    // Send TX_HTTPC at start if enabled (for lost connection cases)
+                    if (conf.getProperty('profile_httpc_start_step_enabled', false)) {
+                        ctx.active_httpc_hash = false;
+                        let urls = `${ctx.httpc_host}:${ctx.httpc_port}${ctx.httpc_url}`;
+                        let httpcDatas = [urls, ctx.mcallee];
+                        ctx.elapsed = 0;
+                        TraceHttpc.isSlowHttpc(ctx);
+                        AsyncSender.send_packet(PacketTypeEnum.TX_HTTPC, ctx, httpcDatas);
+                    }
                 } catch (e) {
                     Logger.printError('WHATAP-240', 'Http Setup Error', e, false);
                     return original.apply(this, arguments);
@@ -507,6 +544,30 @@ HttpObserver.prototype.inject = function (mod, moduleName) {
                 return original.apply(this, arguments);
             }
 
+            // 진행 중인 요청 정보 저장 (여러 개 추적)
+            const httpcInfo = {
+                host: ctx.httpc_host,
+                port: ctx.httpc_port,
+                url: ctx.httpc_url,
+                mcallee: ctx.mcallee,
+                start_time: ctx.start_time
+            };
+
+            // 배열에 추가
+            if (ctx.activeHttpcList) {
+                ctx.activeHttpcList.push(httpcInfo);
+            }
+
+            // 배열에서 제거하는 헬퍼 함수
+            const removeHttpcInfo = function() {
+                if (ctx.activeHttpcList) {
+                    const index = ctx.activeHttpcList.indexOf(httpcInfo);
+                    if (index > -1) {
+                        ctx.activeHttpcList.splice(index, 1);
+                    }
+                }
+            };
+
             var wrappedCallback;
             if (typeof callback === 'function') {
                 wrappedCallback = function (response) {
@@ -515,7 +576,10 @@ HttpObserver.prototype.inject = function (mod, moduleName) {
                     }
 
                     response.on('end', function () {
-                        // HTTP 클라이언트 에러 처리 - Python 스타일로 단순화
+                        // 배열에서 제거
+                        removeHttpcInfo();
+
+                        // HTTP 클라이언트 에러 처리
                         if (response.statusCode >= 400 && transaction_status_error_enable) {
                             let error = {
                                 class: response.statusMessage,
@@ -538,6 +602,9 @@ HttpObserver.prototype.inject = function (mod, moduleName) {
                     return;
                 }
 
+                // 배열에서 제거
+                removeHttpcInfo();
+
                 const isIgnoreHttpc = shouldIgnoreError(err.code, ctx.httpc_url, httpc_status_ignore, httpc_status_ignore_set);
 
                 const networkErrorToStatusCode = {
@@ -574,7 +641,6 @@ HttpObserver.prototype.inject = function (mod, moduleName) {
                                     bodyData = arguments[0].toString('utf8');
                                 }
                                 if (bodyData) {
-                                    console.log(`body Data: ${bodyData}`)
                                     let paramDatas = ['HTTP-PARAMETERS', options.method, bodyData];
                                     AsyncSender.send_packet(PacketTypeEnum.TX_SECURE_MSG, ctx, paramDatas);
                                 }
@@ -591,12 +657,16 @@ HttpObserver.prototype.inject = function (mod, moduleName) {
         }
     });
 
-    // HTTP 클라이언트 종료 처리 - 단순화
     function endHttpc(ctx) {
         if (ctx == null) {
             return;
         }
 
+        // If profile_httpc_start_step_enabled is true, TX_HTTPC was already sent at start
+        if (conf.getProperty('profile_httpc_start_step_enabled', false)) {
+            return;
+        }
+
         ctx.active_httpc_hash = false;
         let urls = `${ctx.httpc_host}:${ctx.httpc_port}${ctx.httpc_url}`;
         let httpcDatas = [urls, ctx.mcallee];
