@@ -11,8 +11,6 @@ var Pack = require('./pack'),
     IntMapValue = require('./../value/int-map-value'),
     IntValue = require('./../value/int-value'),
     FloatValue = require('./../value/float-value'),
-    NETSTAT = require('./netstat'),
-    WEBSOCKET = require('./websocket'),
     IntIntMap = require('../util/intint-map'),
     IntKeyLinkedMap = require('../util/intkey-linkedmap'),
     LongKeyLinkedMap = require('../util/longkey-linkedmap'),
@@ -73,7 +71,6 @@ function CounterPack() {
 
     this.db_num_active = null;
     this.db_num_idle = null;
-    this.netstat = null;
 
     this.host_ip = 0;
     this.proc_fd = 0;
